@@ -288,7 +288,7 @@ class FeatureStoreClient:
         )
 
     def score_batch(
-            self, model_uri: str, df: DataFrame, result_type: str = "double"
+            self, model_uri: str, df: DataFrame, result_type: str = "double", timestamp_key: str = None
     ) -> DataFrame:
         """
         Evaluate the model on the provided :class:`DataFrame <pyspark.sql.DataFrame>`.
@@ -399,6 +399,7 @@ class FeatureStoreClient:
             df=df,
             result_type=result_type,
             client_name=FEATURE_STORE_CLIENT,
+            timestamp_key=timestamp_key,
         )
 
     def publish_table(self, table_name: str, data_source_name: str, cloud_secret_id: str, cloud_secret_key: str,
