@@ -30,3 +30,10 @@ def set_request_header(headers):
         headers["X-Qcloud-User-Id"] = os.environ.get("TEST_USER_ID")
     return headers
 
+
+def is_mock() -> bool:
+    """
+    是否为模拟环境
+    """
+    return os.getenv("IS_MOCK_API") == "true"
+
