@@ -7,7 +7,8 @@ Feast客户端，用于与Feast服务器交互
 import json
 import os
 import re
-from typing import List, Dict, Optional, Any
+from datetime import datetime
+from typing import List, Dict, Optional, Any, Tuple
 try:
     # pyspark 3.5.0 以后
     from pyspark.errors import IllegalArgumentException
@@ -19,6 +20,7 @@ import pytz
 from feast import FeatureStore, RepoConfig, FeatureView
 from pyspark.sql import DataFrame, SparkSession
 from wedata.feature_store.common.store_config.redis import RedisStoreConfig
+from wedata.feature_store.utils import env_utils
 from feast import Entity, FeatureService
 from feast.infra.offline_stores.contrib.spark_offline_store.spark_source import SparkSource
 from feast.infra.online_stores.redis import RedisOnlineStore
@@ -36,8 +38,8 @@ TEMP_FILE_PATH = "/tmp/feast_data/"
 class FeastClient:
 
     def __init__(self, offline_store: SparkSession, online_store_config: RedisStoreConfig = None):
-        project_id = os.getenv("WEDATA_PROJECT_ID", "")
-        remote_path = os.getenv("FEAST_REMOTE_ADDRESS", "")
+        project_id = env_utils.get_project_id()
+        remote_path = env_utils.get_feast_remote_url()
         if offline_store is None or not isinstance(offline_store, SparkSession):
             raise ValueError("offline_store must be provided SparkSession instance")
 
@@ -97,6 +99,7 @@ class FeastClient:
             tags=tags,
             description=description
         )
+        # 确保feature在增量服务时获取的数据时间范围时正确的。
         self._apply_feature_view(table_name, entities, feature_view)
 
     def _apply_feature_view(self, table_name, entities, feature_view: FeatureView):
@@ -144,8 +147,6 @@ class FeastClient:
                 self._client.apply(feature_service)
             self._client.registry.delete_feature_view(feast_table_name, self._client.project)
 
-
-
     def get_feature_view(self, table_name: str):
         feast_table_name = translate_table_name_to_feast(table_name)
         return self._client.get_feature_view(feast_table_name)
@@ -160,11 +161,10 @@ class FeastClient:
             raise ValueError(f"Table {table_name} not found in Feast")
 
         if self._client.config.online_store.type == "redis":
-            print("redis table_view join_keys:", table_view.join_keys)
             redis_online_store = RedisOnlineStore()
             redis_online_store.delete_table(self._client.config, table_view)
             table_view.online = False
-            table_view.materialization_intervals = []
+            table_view.update_materialization_intervals(get_materialization_default_time())
             self._client.apply(table_view)
         else:
             raise ValueError(f"Unsupported online store type: {self._client.config.online_store.type}")
@@ -361,6 +361,7 @@ def _create_table_to_feature_view(
         source=resources,
     )
     feature_view.online = False
+    feature_view.update_materialization_intervals([(datetime(1990, 1, 1), datetime(1990, 1, 1))])
     return feature_view
 
 
@@ -465,18 +466,22 @@ def translate_table_name_to_feast(table_name: str):
         raise ValueError(f"Invalid table name: {table_name}")
 
 
-if __name__ == '__main__':
-    import datetime
-    FeastClient = FeastClient()
-    FeastClient.client.registry.delete_data_source(name="xxxxx")
-    FeastClient.client.registry.delete_entity("xxxxx", )
-    FeastClient.client.registry.delete_feature_view()
-    FeastClient.client.registry.get_feature_view()
-    FeastClient.client.registry.delete_feature_service()
-    FeastClient.client.get_historical_features()
-    feature_view = FeastClient.client.get_feature_view(name="xxxxx")
-    feature_view.source.get_table_query_string()
-    feast_table_name = "xxx"
-    from wedata.feature_store.utils.common_utils import build_full_table_name
-    feast_table_name = translate_table_name_to_feast(build_full_table_name(table_name, database_name))
-    FeastClient.client.materialize(start_date=datetime.datetime(2021,1,1), end_date=datetime.datetime.now(), feature_views=[feast_table_name])
\ No newline at end of file
+def get_materialization_default_time() -> List[Tuple[datetime, datetime]]:
+    return [(datetime(1990, 1, 1), datetime(1990, 1, 1))]
+
+
+# if __name__ == '__main__':
+#     import datetime
+#     FeastClient = FeastClient()
+#     FeastClient.client.registry.delete_data_source(name="xxxxx")
+#     FeastClient.client.registry.delete_entity("xxxxx", )
+#     FeastClient.client.registry.delete_feature_view()
+#     FeastClient.client.registry.get_feature_view()
+#     FeastClient.client.registry.delete_feature_service()
+#     FeastClient.client.get_historical_features()
+#     feature_view = FeastClient.client.get_feature_view(name="xxxxx")
+#     feature_view.source.get_table_query_string()
+#     feast_table_name = "xxx"
+#     from wedata.feature_store.utils.common_utils import build_full_table_name
+#     feast_table_name = translate_table_name_to_feast(build_full_table_name(table_name, database_name))
+#     FeastClient.client.materialize(start_date=datetime.datetime(2021,1,1), end_date=datetime.datetime.now(), feature_views=[feast_table_name])
\ No newline at end of file
