@@ -123,6 +123,11 @@ class FeatureTableClient:
         """转义SQL值中的特殊字符"""
         return value.replace("'", "''")
 
+    @staticmethod
+    def _check_sequence_element_type(sequence: Sequence[Any], element_type: type) -> bool:
+        """检查序列中的元素是否为指定类型"""
+        return all(isinstance(element, element_type) for element in sequence)
+
     def create_table(
             self,
             name: str,
@@ -165,6 +170,10 @@ class FeatureTableClient:
         primary_keys = self._normalize_params(primary_keys)
         partition_columns = self._normalize_params(partition_columns)
 
+        assert self._check_sequence_element_type(primary_keys, str), "primary_keys must be a list of strings"
+        assert self._check_sequence_element_type(partition_columns, str), "partition_columns must be a list of strings"
+        assert isinstance(timestamp_key, str), "timestamp key must be string"
+
         # 元数据校验
         self._validate_schema(df, schema)
         self._validate_key_exists(primary_keys, timestamp_key)
@@ -196,7 +205,7 @@ class FeatureTableClient:
             raise ValueError(f"Error checking table existence: {str(e)}") from e
 
         try:
-            self._sync_table_info(table_name=name, action_name="CREATE",
+            self._sync_table_info(table_name=name, action_name="create",
                                   database_name=env_utils.get_database_name(database_name),
                                   data_source_name=data_source_name, engine_name=env_utils.get_engine_name(),
                                   is_try=True)
@@ -326,7 +335,7 @@ class FeatureTableClient:
         print(f"create table {name} done")
 
         try:
-            self._sync_table_info(table_name=name, action_name="CREATE",
+            self._sync_table_info(table_name=name, action_name="create",
                                   database_name=env_utils.get_database_name(database_name),
                                   data_source_name=data_source_name, engine_name=env_utils.get_engine_name(),
                                   is_try=False)
@@ -444,6 +453,10 @@ class FeatureTableClient:
         common_utils.validate_table_name(name)
         common_utils.validate_database(database_name)
 
+        if primary_keys:
+            assert self._check_sequence_element_type(primary_keys, str), "primary_keys must be a list of strings"
+        assert isinstance(timestamp_key, str), "timestamp key must be string"
+
         # 构建完整表名
         table_name = common_utils.build_full_table_name(name, database_name)
 
@@ -456,11 +469,12 @@ class FeatureTableClient:
 
             # 检查Primary Key和Timestamp Key是否为空
             if engine_type == engine_type.ICEBERG_ENGINE and props.get("format-version", "") == "2":
-                if props.get('dlc.ao.data.govern.sorted.keys', "") == "":
-                    raise ValueError(
-                        "table dlc.ao.data.govern.sorted.keys is empty. you must set dlc.ao.data.govern.sorted.keys")
-                else:
-                    primary_keys = props.get('dlc.ao.data.govern.sorted.keys').split(",")
+                if not primary_keys:
+                    if props.get('dlc.ao.data.govern.sorted.keys', "") == "":
+                        raise ValueError(
+                            "table dlc.ao.data.govern.sorted.keys is empty. you must set dlc.ao.data.govern.sorted.keys")
+                    else:
+                        primary_keys = props.get('dlc.ao.data.govern.sorted.keys').split(",")
             elif engine_type == engine_type.HIVE_ENGINE:
                 if not primary_keys:
                     raise ValueError("primary_keys cannot be None for HIVE_ENGINE")
@@ -512,7 +526,7 @@ class FeatureTableClient:
             alter_sql = f"ALTER TABLE {table_name} SET TBLPROPERTIES ({props_str})"
 
             try:
-                self._sync_table_info(table_name=name, action_name="CREATE",
+                self._sync_table_info(table_name=name, action_name="create",
                                   database_name=env_utils.get_database_name(database_name),
                                   data_source_name=data_source_name, engine_name=env_utils.get_engine_name(), is_try=True)
             except tencentcloud.common.exception.TencentCloudSDKException as e:
@@ -527,7 +541,7 @@ class FeatureTableClient:
             print(f"Successfully register table '{table_name}'")
 
             try:
-                self._sync_table_info(table_name=name, action_name="CREATE",
+                self._sync_table_info(table_name=name, action_name="create",
                                   database_name=env_utils.get_database_name(database_name),
                                   data_source_name=data_source_name, engine_name=env_utils.get_engine_name(), is_try=False)
             except tencentcloud.common.exception.TencentCloudSDKException as e:
@@ -613,9 +627,6 @@ class FeatureTableClient:
                 print(f"Table '{name}' does not exist")
                 return
 
-            # 检查
-            df = self._spark.table(tableName=table_name)
-
             try:
                 feature_view = self._feast_client.get_feature_view(table_name)
             except Exception as e:
@@ -624,7 +635,7 @@ class FeatureTableClient:
                 if feature_view.online:
                     raise ValueError(f"Table '{name}' has a online table, please call drop_online_table first")
             try:
-                self._sync_table_info(table_name=name, action_name="DELETE",
+                self._sync_table_info(table_name=name, action_name="delete",
                                   database_name=env_utils.get_database_name(database_name),
                                   data_source_name="", engine_name=env_utils.get_engine_name(), is_try=True)
             except tencentcloud.common.exception.TencentCloudSDKException as e:
@@ -642,7 +653,7 @@ class FeatureTableClient:
                 print(f"Table '{name}' removed from feast")
 
             try:
-                self._sync_table_info(table_name=name, action_name="DELETE",
+                self._sync_table_info(table_name=name, action_name="delete",
                                       database_name=env_utils.get_database_name(database_name),
                                       data_source_name="", engine_name=env_utils.get_engine_name(), is_try=False)
             except tencentcloud.common.exception.TencentCloudSDKException as e:
@@ -710,7 +721,7 @@ class FeatureTableClient:
                     full_table_name=full_table_name,
                     columns_name=columns_name_list,
                     entity_rows=[result_row.asDict()])
-                # print(online_view[schema_name_list])
+                print("=====>read online dataframe:\n", online_view[schema_name_list])
                 return self._spark.createDataFrame(online_view[schema_name_list], schema=schema, verifySchema=False)
             else:
                 return self._spark.createDataFrame([])
@@ -719,7 +730,7 @@ class FeatureTableClient:
                 full_table_name=full_table_name,
                 columns_name=columns_name_list,
                 entity_rows=entity_row)
-            # print(online_view[columns_name_list])
+            print("=====>read online dataframe:\n", online_view[schema_name_list])
             return self._spark.createDataFrame(online_view[schema_name_list], schema=schema, verifySchema=False)
 
     def get_table(
@@ -881,27 +892,22 @@ class FeatureTableClient:
             online_feature_config.DB = online_config.db
 
         offline_feature_config = OfflineFeatureConfiguration()
-        offline_feature_config.DatabaseName = database_name if database_name else os.environ.get(
-            "WEDATA_DEFAULT_FEATURE_STORE_DATABASE")
+        offline_feature_config.DatabaseName = env_utils.get_database_name(database_name)
         offline_feature_config.TableName = table_name
 
         offline_feature_config.PrimaryKeys, offline_feature_config.TimestampColumn = self._get_table_primary_keys_and_timestamp_key(
             full_table_name)
 
         offline_feature_config.DatasourceName = data_source_name
-        offline_feature_config.DatasourceType = "DLC" if os.environ.get("DLC_REGION") else "EMR"
-        offline_feature_config.EngineName = os.environ.get("KERNEL_ENGINE")
+        offline_feature_config.DatasourceType = env_utils.get_engine_type()
+        offline_feature_config.EngineName = env_utils.get_engine_name()
 
         api_requests = CreateOnlineFeatureTableRequest()
         api_requests.OfflineFeatureConfiguration = offline_feature_config
         api_requests.OnlineFeatureConfiguration = online_feature_config
         api_requests.TaskSchedulerConfiguration = cycle_obj
-        api_requests.ProjectId = os.environ.get("WEDATA_PROJECT_ID")
-        if offline_feature_config.DatasourceType == "DLC":
-            region = os.environ.get("DLC_REGION")
-        else:
-            region = os.environ.get("EMR_REGION")
-
+        api_requests.ProjectId = env_utils.get_project_id()
+        region = env_utils.get_region()
         if not os.environ.get("RESOURCE_GROUP_ID", ""):
             res_group_item = _get_default_resource_group(
                 api_requests.ProjectId, cloud_secret_id, cloud_secret_key, region)
@@ -919,7 +925,18 @@ class FeatureTableClient:
         # 构建完整表名
         full_table_name = common_utils.build_full_table_name(table_name, database_name)
         feast_client = FeastClient(self._spark, online_config)
+        try:
+            self._sync_table_info(table_name=table_name, database_name=database_name, action_name="delete_online",
+                                  data_source_name="", engine_name=env_utils.get_engine_name(), is_try=True)
+        except Exception as e:
+            raise RuntimeError(f"drop online table failed. table_name: {full_table_name}. {str(e)}")
+
         feast_client.remove_online_table(full_table_name)
+        try:
+            self._sync_table_info(table_name=table_name, database_name=database_name, action_name="delete_online",
+                                  data_source_name="", engine_name=env_utils.get_engine_name(), is_try=False)
+        except Exception as e:
+            raise RuntimeError(f"drop online table failed. table_name: {full_table_name}. {str(e)}")
         print(f"drop online table success. table_name: {full_table_name}")
 
     def _get_table_primary_keys_and_timestamp_key(self, full_table_name: str) -> 'str, str':
@@ -954,7 +971,6 @@ def _get_default_resource_group(project_id: str, secret_id: str, secret_key: str
 def _refresh_table(project_id: str, secret_id: str, secret_key: str, region: str, table_name: str,
                    action: str, database_name: str, data_source_name: str, data_source_type: str,
                    engine_name: str, is_try: bool):
-    return
     client = FeatureCloudSDK(secret_id=secret_id, secret_key=secret_key, region=region)
     request = RefreshFeatureTableRequest()
     request.ProjectId = project_id
@@ -963,7 +979,7 @@ def _refresh_table(project_id: str, secret_id: str, secret_key: str, region: str
     request.DatasourceName = data_source_name
     request.DatasourceType = data_source_type
     request.EngineName = engine_name
-    request.Action = action
+    request.ActionName = action
     request.IsTry = is_try
     resp = client.RefreshFeatureTable(request)
     return resp
\ No newline at end of file
