@@ -360,6 +360,7 @@ class TrainingSetClient:
         env_manager: Optional[str] = None,
         local_uri: Optional[str] = None,
         params: Optional[dict[str, Any]] = None,
+        timestamp_key: str = None,
         **kwargs,
     ) -> DataFrame:
         # TODO:ML 待确定是否需要
@@ -423,8 +424,11 @@ class TrainingSetClient:
 
         # Validate that columns needed for joining feature tables exist and are not duplicates.
         feature_input_keys = []
+        print("====>timestamp_key:", timestamp_key)
         for fci in feature_spec.feature_column_infos:
+            print("====>fci:", fci.lookup_key)
             feature_input_keys.extend([k for k in fci.lookup_key])
+
         on_demand_input_names = uc_utils.get_unique_list_order(
             [
                 input_name
@@ -438,12 +442,16 @@ class TrainingSetClient:
         ]
         # print(f"wedata source_data_names:{source_data_names}")
 
+        print("===>source_data_names:", source_data_names)
+
         feature_output_names = [
             fci.output_name for fci in feature_spec.feature_column_infos
         ]
+        print("====>feature_output_names:", feature_output_names)
         on_demand_output_names = [
             odci.output_name for odci in feature_spec.on_demand_column_infos
         ]
+        print("====>on_demand_output_names:", on_demand_output_names)
         all_output_names = set(
             source_data_names + feature_output_names + on_demand_output_names
         )
